@@ -20,7 +20,6 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -33,15 +32,15 @@
 
 /* text/enriched is rfc1896 */
 
-typedef char * (*EnrichedParamParser) (const char *inptr, int inlen);
+typedef gchar * (*EnrichedParamParser) (const gchar *inptr, gint inlen);
 
-static char *param_parse_colour (const char *inptr, int inlen);
-static char *param_parse_font (const char *inptr, int inlen);
-static char *param_parse_lang (const char *inptr, int inlen);
+static gchar *param_parse_colour (const gchar *inptr, gint inlen);
+static gchar *param_parse_font (const gchar *inptr, gint inlen);
+static gchar *param_parse_lang (const gchar *inptr, gint inlen);
 
 static struct {
-	char *enriched;
-	char *html;
+	const gchar *enriched;
+	const gchar *html;
 	gboolean needs_param;
 	EnrichedParamParser parse_param; /* parses *and* validates the input */
 } enriched_tags[] = {
@@ -77,11 +76,11 @@ static struct {
 	{ "/color",      "</font>",             FALSE, NULL               },
 	{ "lang",        "<span lang=\"%s\">",  TRUE,  param_parse_lang   },
 	{ "/lang",       "</span>",             FALSE, NULL               },
-	
+
 	/* don't handle this tag yet... */
 	{ "paraindent",  "<!-- ",               /* TRUE */ FALSE, NULL    },
 	{ "/paraindent", " -->",                FALSE, NULL               },
-	
+
 	/* as soon as we support all the tags that can have a param
 	 * tag argument, these should be unnecessary, but we'll keep
 	 * them anyway just in case? */
@@ -93,26 +92,23 @@ static struct {
 
 static GHashTable *enriched_hash = NULL;
 
-
 static void camel_mime_filter_enriched_class_init (CamelMimeFilterEnrichedClass *klass);
 static void camel_mime_filter_enriched_init       (CamelMimeFilterEnriched *filter);
 static void camel_mime_filter_enriched_finalize   (CamelObject *obj);
 
-static void filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-			   char **out, size_t *outlen, size_t *outprespace);
-static void filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-			     char **out, size_t *outlen, size_t *outprespace);
+static void filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+			   gchar **out, gsize *outlen, gsize *outprespace);
+static void filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+			     gchar **out, gsize *outlen, gsize *outprespace);
 static void filter_reset (CamelMimeFilter *filter);
 
-
 static CamelMimeFilterClass *parent_class = NULL;
 
-
 CamelType
 camel_mime_filter_enriched_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (),
 					    "CamelMimeFilterEnriched",
@@ -123,7 +119,7 @@ camel_mime_filter_enriched_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_filter_enriched_init,
 					    (CamelObjectFinalizeFunc) camel_mime_filter_enriched_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -131,19 +127,21 @@ static void
 camel_mime_filter_enriched_class_init (CamelMimeFilterEnrichedClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	int i;
-	
+	gint i;
+
 	parent_class = CAMEL_MIME_FILTER_CLASS (camel_mime_filter_get_type ());
-	
+
 	filter_class->reset = filter_reset;
 	filter_class->filter = filter_filter;
 	filter_class->complete = filter_complete;
-	
+
 	if (!enriched_hash) {
 		enriched_hash = g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
 		for (i = 0; i < NUM_ENRICHED_TAGS; i++)
-			g_hash_table_insert (enriched_hash, enriched_tags[i].enriched,
-					     enriched_tags[i].html);
+			g_hash_table_insert (
+				enriched_hash,
+				(gpointer) enriched_tags[i].enriched,
+				(gpointer) enriched_tags[i].html);
 	}
 }
 
@@ -160,46 +158,45 @@ camel_mime_filter_enriched_init (CamelMimeFilterEnriched *filter)
 	filter->nofill = 0;
 }
 
-
 #if 0
 static gboolean
-enriched_tag_needs_param (const char *tag)
+enriched_tag_needs_param (const gchar *tag)
 {
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < NUM_ENRICHED_TAGS; i++)
 		if (!g_ascii_strcasecmp (tag, enriched_tags[i].enriched))
 			return enriched_tags[i].needs_param;
-	
+
 	return FALSE;
 }
 #endif
 
 static gboolean
-html_tag_needs_param (const char *tag)
+html_tag_needs_param (const gchar *tag)
 {
 	return strstr (tag, "%s") != NULL;
 }
 
-static const char *valid_colours[] = {
+static const gchar *valid_colours[] = {
 	"red", "green", "blue", "yellow", "cyan", "magenta", "black", "white"
 };
 
 #define NUM_VALID_COLOURS  (sizeof (valid_colours) / sizeof (valid_colours[0]))
 
-static char *
-param_parse_colour (const char *inptr, int inlen)
+static gchar *
+param_parse_colour (const gchar *inptr, gint inlen)
 {
-	const char *inend, *end;
+	const gchar *inend, *end;
 	guint32 rgb = 0;
 	guint v;
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < NUM_VALID_COLOURS; i++) {
 		if (!g_ascii_strncasecmp (inptr, valid_colours[i], inlen))
 			return g_strdup (valid_colours[i]);
 	}
-	
+
 	/* check for numeric r/g/b in the format: ####,####,#### */
 	if (inptr[4] != ',' || inptr[9] != ',') {
 		/* okay, mailer must have used a string name that
@@ -209,99 +206,99 @@ param_parse_colour (const char *inptr, int inlen)
 		inend = inptr + inlen;
 		while (end < inend && ((*end >= 'a' && *end <= 'z') || (*end >= 'A' && *end <= 'Z')))
 			end++;
-		
+
 		return g_strndup (inptr, end - inptr);
 	}
-	
+
 	for (i = 0; i < 3; i++) {
-		v = strtoul (inptr, (char **) &end, 16);
+		v = strtoul (inptr, (gchar **) &end, 16);
 		if (end != inptr + 4)
 			goto invalid_format;
-		
+
 		v >>= 8;
 		rgb = (rgb << 8) | (v & 0xff);
-		
+
 		inptr += 5;
 	}
-	
+
 	return g_strdup_printf ("#%.6X", rgb);
-	
+
  invalid_format:
-	
+
 	/* default colour? */
 	return g_strdup ("black");
 }
 
-static char *
-param_parse_font (const char *fontfamily, int inlen)
+static gchar *
+param_parse_font (const gchar *fontfamily, gint inlen)
 {
-	register const char *inptr = fontfamily;
-	const char *inend = inptr + inlen;
-	
+	register const gchar *inptr = fontfamily;
+	const gchar *inend = inptr + inlen;
+
 	/* don't allow any of '"', '<', nor '>' */
 	while (inptr < inend && *inptr != '"' && *inptr != '<' && *inptr != '>')
 		inptr++;
-	
+
 	return g_strndup (fontfamily, inptr - fontfamily);
 }
 
-static char *
-param_parse_lang (const char *lang, int inlen)
+static gchar *
+param_parse_lang (const gchar *lang, gint inlen)
 {
-	register const char *inptr = lang;
-	const char *inend = inptr + inlen;
-	
+	register const gchar *inptr = lang;
+	const gchar *inend = inptr + inlen;
+
 	/* don't allow any of '"', '<', nor '>' */
 	while (inptr < inend && *inptr != '"' && *inptr != '<' && *inptr != '>')
 		inptr++;
-	
+
 	return g_strndup (lang, inptr - lang);
 }
 
-static char *
-param_parse (const char *enriched, const char *inptr, int inlen)
+static gchar *
+param_parse (const gchar *enriched, const gchar *inptr, gint inlen)
 {
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < NUM_ENRICHED_TAGS; i++) {
 		if (!g_ascii_strcasecmp (enriched, enriched_tags[i].enriched))
 			return enriched_tags[i].parse_param (inptr, inlen);
 	}
-	
+
 	g_assert_not_reached ();
-	
+
 	return NULL;
 }
 
 #define IS_RICHTEXT CAMEL_MIME_FILTER_ENRICHED_IS_RICHTEXT
 
 static void
-enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
-		  char **out, size_t *outlen, size_t *outprespace, gboolean flush)
+enriched_to_html (CamelMimeFilter *filter, const gchar *in, gsize inlen, gsize prespace,
+		  gchar **out, gsize *outlen, gsize *outprespace, gboolean flush)
 {
 	CamelMimeFilterEnriched *enriched = (CamelMimeFilterEnriched *) filter;
-	const char *tag, *inend, *outend;
-	register const char *inptr;
-	register char *outptr;
-	
+	const gchar *tag, *inend, *outend;
+	register const gchar *inptr;
+	register gchar *outptr;
+
 	camel_mime_filter_set_size (filter, inlen * 2 + 6, FALSE);
-	
+
 	inptr = in;
 	inend = in + inlen;
 	outptr = filter->outbuf;
 	outend = filter->outbuf + filter->outsize;
-	
+
  retry:
 	do {
 		while (inptr < inend && outptr < outend && !strchr (" <>&\n", *inptr))
 			*outptr++ = *inptr++;
-		
+
 		if (outptr == outend)
 			goto backup;
-		
+
 		if ((inptr + 1) >= inend)
 			break;
-		
+
 		switch (*inptr++) {
 		case ' ':
 			while (inptr < inend && (outptr + 7) < outend && *inptr == ' ') {
@@ -309,10 +306,10 @@ enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespa
 				outptr += 6;
 				inptr++;
 			}
-			
+
 			if (outptr < outend)
 				*outptr++ = ' ';
-			
+
 			break;
 		case '\n':
 			if (!(enriched->flags & IS_RICHTEXT)) {
@@ -330,7 +327,7 @@ enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespa
 						inptr--;
 						goto backup;
 					}
-					
+
 					while (inptr < inend && (outptr + 4) < outend && *inptr == '\n') {
 						memcpy (outptr, "<br>", 4);
 						outptr += 4;
@@ -395,16 +392,16 @@ enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespa
 					goto backup;
 				}
 			}
-			
+
 			tag = inptr;
 			while (inptr < inend && *inptr != '>')
 				inptr++;
-			
+
 			if (inptr == inend) {
 				inptr = tag - 1;
 				goto need_input;
 			}
-			
+
 			if (!g_ascii_strncasecmp (tag, "nofill>", 7)) {
 				if ((outptr + 5) < outend) {
 					enriched->nofill++;
@@ -420,61 +417,61 @@ enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespa
 					goto backup;
 				}
 			} else {
-				const char *html_tag;
-				char *enriched_tag;
-				int len;
-				
+				const gchar *html_tag;
+				gchar *enriched_tag;
+				gint len;
+
 				len = inptr - tag;
 				enriched_tag = g_alloca (len + 1);
 				memcpy (enriched_tag, tag, len);
 				enriched_tag[len] = '\0';
-				
+
 				html_tag = g_hash_table_lookup (enriched_hash, enriched_tag);
-				
+
 				if (html_tag) {
 					if (html_tag_needs_param (html_tag)) {
-						const char *start;
-						char *param;
-						
+						const gchar *start;
+						gchar *param;
+
 						while (inptr < inend && *inptr != '<')
 							inptr++;
-						
+
 						if (inptr == inend || (inend - inptr) <= 15) {
 							inptr = tag - 1;
 							goto need_input;
 						}
-						
+
 						if (g_ascii_strncasecmp (inptr, "<param>", 7) != 0) {
 							/* ignore the enriched command tag... */
 							inptr -= 1;
 							goto loop;
 						}
-						
+
 						inptr += 7;
 						start = inptr;
-						
+
 						while (inptr < inend && *inptr != '<')
 							inptr++;
-						
+
 						if (inptr == inend || (inend - inptr) <= 8) {
 							inptr = tag - 1;
 							goto need_input;
 						}
-						
+
 						if (g_ascii_strncasecmp (inptr, "</param>", 8) != 0) {
 							/* ignore the enriched command tag... */
 							inptr += 7;
 							goto loop;
 						}
-						
+
 						len = inptr - start;
 						param = param_parse (enriched_tag, start, len);
 						len = strlen (param);
-						
+
 						inptr += 7;
-						
+
 						len += strlen (html_tag);
-						
+
 						if ((outptr + len) < outend) {
 							outptr += snprintf (outptr, len, html_tag, param);
 							g_free (param);
@@ -495,7 +492,7 @@ enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespa
 					}
 				}
 			}
-			
+
 		loop:
 			inptr++;
 			break;
@@ -503,53 +500,53 @@ enriched_to_html (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespa
 			break;
 		}
 	} while (inptr < inend);
-	
+
  need_input:
-	
+
 	/* the reason we ignore @flush here is because if there isn't
            enough input to parse a tag, then there's nothing we can
            do. */
-	
+
 	if (inptr < inend)
 		camel_mime_filter_backup (filter, inptr, (unsigned) (inend - inptr));
-	
+
 	*out = filter->outbuf;
 	*outlen = outptr - filter->outbuf;
 	*outprespace = filter->outpre;
-	
+
 	return;
-	
+
  backup:
-	
+
 	if (flush) {
-		size_t offset, grow;
-		
+		gsize offset, grow;
+
 		grow = (inend - inptr) * 2 + 20;
 		offset = outptr - filter->outbuf;
 		camel_mime_filter_set_size (filter, filter->outsize + grow, TRUE);
 		outend = filter->outbuf + filter->outsize;
 		outptr = filter->outbuf + offset;
-		
+
 		goto retry;
 	} else {
 		camel_mime_filter_backup (filter, inptr, (unsigned) (inend - inptr));
 	}
-	
+
 	*out = filter->outbuf;
 	*outlen = outptr - filter->outbuf;
 	*outprespace = filter->outpre;
 }
 
 static void
-filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-	       char **out, size_t *outlen, size_t *outprespace)
+filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+	       gchar **out, gsize *outlen, gsize *outprespace)
 {
 	enriched_to_html (filter, in, len, prespace, out, outlen, outprespace, FALSE);
 }
 
-static void 
-filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-		 char **out, size_t *outlen, size_t *outprespace)
+static void
+filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+		 gchar **out, gsize *outlen, gsize *outprespace)
 {
 	enriched_to_html (filter, in, len, prespace, out, outlen, outprespace, TRUE);
 }
@@ -558,11 +555,10 @@ static void
 filter_reset (CamelMimeFilter *filter)
 {
 	CamelMimeFilterEnriched *enriched = (CamelMimeFilterEnriched *) filter;
-	
+
 	enriched->nofill = 0;
 }
 
-
 /**
  * camel_mime_filter_enriched_new:
  * @flags: bitwise set of flags to specify filter behaviour
@@ -576,14 +572,13 @@ CamelMimeFilter *
 camel_mime_filter_enriched_new (guint32 flags)
 {
 	CamelMimeFilterEnriched *new;
-	
+
 	new = (CamelMimeFilterEnriched *) camel_object_new (CAMEL_TYPE_MIME_FILTER_ENRICHED);
 	new->flags = flags;
-	
+
 	return CAMEL_MIME_FILTER (new);
 }
 
-
 /**
  * camel_enriched_to_html:
  * @in: input textual string
@@ -595,21 +590,21 @@ camel_mime_filter_enriched_new (guint32 flags)
  * Returns: a newly allocated string containing the enriched or
  * richtext version of @in.
  **/
-char *
-camel_enriched_to_html(const char *in, guint32 flags)
+gchar *
+camel_enriched_to_html(const gchar *in, guint32 flags)
 {
 	CamelMimeFilter *filter;
-	size_t outlen, outpre;
-	char *outbuf;
+	gsize outlen, outpre;
+	gchar *outbuf;
 
 	if (in == NULL)
 		return NULL;
-	
+
 	filter = camel_mime_filter_enriched_new(flags);
-	
-	camel_mime_filter_complete(filter, (char *)in, strlen(in), 0, &outbuf, &outlen, &outpre);
+
+	camel_mime_filter_complete(filter, (gchar *)in, strlen(in), 0, &outbuf, &outlen, &outpre);
 	outbuf = g_strndup (outbuf, outlen);
 	camel_object_unref (filter);
-	
+
 	return outbuf;
 }
