@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,6 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -48,7 +47,7 @@
 #define CONVERT_ADDRSPEC  CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES
 
 static struct {
-	unsigned int mask;
+	guint mask;
 	urlpattern_t pattern;
 } patterns[] = {
 	{ CONVERT_WEB_URLS, { "file://",   "",        camel_url_file_start,     camel_url_file_end     } },
@@ -77,7 +76,6 @@ static void camel_mime_filter_tohtml_finalize   (CamelObject *obj);
 
 static CamelMimeFilterClass *camel_mime_filter_tohtml_parent;
 
-
 CamelType
 camel_mime_filter_tohtml_get_type (void)
 {
@@ -116,11 +114,10 @@ camel_mime_filter_tohtml_init (CamelMimeFilterToHTML *filter)
 	filter->pre_open = FALSE;
 }
 
-
-static char *
-check_size (CamelMimeFilter *filter, char *outptr, char **outend, size_t len)
+static gchar *
+check_size (CamelMimeFilter *filter, gchar *outptr, gchar **outend, gsize len)
 {
-	size_t offset;
+	gsize offset;
 
 	if (*outend - outptr >= len)
 		return outptr;
@@ -134,11 +131,23 @@ check_size (CamelMimeFilter *filter, char *outptr, char **outend, size_t len)
 	return filter->outbuf + offset;
 }
 
-static int
-citation_depth (const char *in)
+static gchar *
+append_string_verbatim (CamelMimeFilter *filter, const gchar *str, gchar *outptr, gchar **outend)
 {
-	register const char *inptr = in;
-	int depth = 1;
+	gsize len = strlen (str);
+
+	outptr = check_size (filter, outptr, outend, len);
+	memcpy(outptr, str, len);
+	outptr += len;
+
+	return outptr;
+}
+
+static gint
+citation_depth (const gchar *in)
+{
+	register const gchar *inptr = in;
+	gint depth = 1;
 
 	if (*inptr++ != '>')
 		return 0;
@@ -162,11 +171,11 @@ citation_depth (const char *in)
 	return depth;
 }
 
-static char *
-writeln (CamelMimeFilter *filter, const unsigned char *in, const unsigned char *inend, char *outptr, char **outend)
+static gchar *
+writeln (CamelMimeFilter *filter, const guchar *in, const guchar *inend, gchar *outptr, gchar **outend)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	const unsigned char *inptr = in;
+	const guchar *inptr = in;
 
 	while (inptr < inend) {
 		guint32 u;
@@ -230,14 +239,15 @@ writeln (CamelMimeFilter *filter, const unsigned char *in, const unsigned char *
 }
 
 static void
-html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
-	      char **out, size_t *outlen, size_t *outprespace, gboolean flush)
+html_convert (CamelMimeFilter *filter, const gchar *in, gsize inlen, gsize prespace,
+	      gchar **out, gsize *outlen, gsize *outprespace, gboolean flush)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	register char *inptr, *outptr;
-	char *start, *outend;
-	const char *inend;
-	int depth;
+	const gchar *inptr;
+	gchar *outptr, *outend;
+	const gchar *start;
+	const gchar *inend;
+	gint depth;
 
 	if (inlen == 0) {
 		if (html->pre_open) {
@@ -251,7 +261,7 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			*outlen = outptr - filter->outbuf;
 			*outprespace = filter->outpre;
 		} else {
-			*out = in;
+			*out = (gchar *) in;
 			*outlen = 0;
 			*outprespace = 0;
 		}
@@ -275,10 +285,10 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 	do {
 		while (inptr < inend && *inptr != '\n')
 			inptr++;
-		
+
 		if (inptr >= inend && !flush)
 			break;
-		
+
 		html->column = 0;
 		depth = 0;
 
@@ -303,7 +313,7 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 
 #define CONVERT_URLS (CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS | CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES)
 		if (html->flags & CONVERT_URLS) {
-			size_t matchlen, buflen, len;
+			gsize matchlen, len;
 			urlmatch_t match;
 
 			len = inptr - start;
@@ -311,7 +321,7 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			do {
 				if (camel_url_scanner_scan (html->scanner, start, len, &match)) {
 					/* write out anything before the first regex match */
-					outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)start + match.um_so,
+					outptr = writeln (filter, (const guchar *)start, (const guchar *)start + match.um_so,
 							  outptr, &outend);
 
 					start += match.um_so;
@@ -319,33 +329,38 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 
 					matchlen = match.um_eo - match.um_so;
 
-					buflen = 20 + strlen (match.prefix) + matchlen + matchlen;
-					outptr = check_size (filter, outptr, &outend, buflen);
-
 					/* write out the href tag */
-					outptr = g_stpcpy (outptr, "<a href=\"");
-					outptr = g_stpcpy (outptr, match.prefix);
-					memcpy (outptr, start, matchlen);
-					outptr += matchlen;
-					outptr = g_stpcpy (outptr, "\">");
+					outptr = append_string_verbatim (filter, "<a href=\"", outptr, &outend);
+					/* prefix shouldn't need escaping, but let's be safe */
+					outptr = writeln (filter,
+							(const guchar *)match.prefix,
+							(const guchar *)match.prefix + strlen (match.prefix),
+							outptr, &outend);
+					outptr = writeln (filter,
+							(const guchar *)start,
+							(const guchar *)start + matchlen,
+							outptr, &outend);
+					outptr = append_string_verbatim (filter, "\">", outptr, &outend);
 
 					/* now write the matched string */
-					memcpy (outptr, start, matchlen);
+					outptr = writeln (filter,
+							(const guchar *)start,
+							(const guchar *)start + matchlen,
+							outptr, &outend);
 					html->column += matchlen;
-					outptr += matchlen;
 					start += matchlen;
 					len -= matchlen;
 
 					/* close the href tag */
-					outptr = g_stpcpy (outptr, "</a>");
+					outptr = append_string_verbatim (filter, "</a>", outptr, &outend);
 				} else {
 					/* nothing matched so write out the remainder of this line buffer */
-					outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)start + len, outptr, &outend);
+					outptr = writeln (filter, (const guchar *)start, (const guchar *)start + len, outptr, &outend);
 					break;
 				}
 			} while (len > 0);
 		} else {
-			outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)inptr, outptr, &outend);
+			outptr = writeln (filter, (const guchar *)start, (const guchar *)inptr, outptr, &outend);
 		}
 
 		if ((html->flags & CAMEL_MIME_FILTER_TOHTML_MARK_CITATION) && depth > 0) {
@@ -368,7 +383,7 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 	if (flush) {
 		/* flush the rest of our input buffer */
 		if (start < inend)
-			outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)inend, outptr, &outend);
+			outptr = writeln (filter, (const guchar *)start, (const guchar *)inend, outptr, &outend);
 
 		if (html->pre_open) {
 			/* close the pre-tag */
@@ -386,15 +401,15 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 }
 
 static void
-filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-	       char **out, size_t *outlen, size_t *outprespace)
+filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+	       gchar **out, gsize *outlen, gsize *outprespace)
 {
 	html_convert (filter, in, len, prespace, out, outlen, outprespace, FALSE);
 }
 
 static void
-filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-		 char **out, size_t *outlen, size_t *outprespace)
+filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+		 gchar **out, gsize *outlen, gsize *outprespace)
 {
 	html_convert (filter, in, len, prespace, out, outlen, outprespace, TRUE);
 }
@@ -420,7 +435,6 @@ camel_mime_filter_tohtml_class_init (CamelMimeFilterToHTMLClass *klass)
 	filter_class->complete = filter_complete;
 }
 
-
 /**
  * camel_mime_filter_tohtml_new:
  * @flags: bitwise flags defining the behaviour
@@ -429,13 +443,13 @@ camel_mime_filter_tohtml_class_init (CamelMimeFilterToHTMLClass *klass)
  * Create a new #CamelMimeFilterToHTML object to convert plain text
  * into HTML.
  *
- * Returns a new #CamelMimeFilterToHTML object
+ * Returns: a new #CamelMimeFilterToHTML object
  **/
 CamelMimeFilter *
 camel_mime_filter_tohtml_new (guint32 flags, guint32 colour)
 {
 	CamelMimeFilterToHTML *new;
-	int i;
+	gint i;
 
 	new = CAMEL_MIME_FILTER_TOHTML (camel_object_new (camel_mime_filter_tohtml_get_type ()));
 
@@ -450,7 +464,6 @@ camel_mime_filter_tohtml_new (guint32 flags, guint32 colour)
 	return CAMEL_MIME_FILTER (new);
 }
 
-
 /**
  * camel_text_to_html:
  * @in: input text
@@ -459,21 +472,21 @@ camel_mime_filter_tohtml_new (guint32 flags, guint32 colour)
  *
  * Convert @in from plain text into HTML.
  *
- * Returns a newly allocated string containing the HTMLified version
+ * Returns: a newly allocated string containing the HTMLified version
  * of @in
  **/
-char *
-camel_text_to_html (const char *in, guint32 flags, guint32 colour)
+gchar *
+camel_text_to_html (const gchar *in, guint32 flags, guint32 colour)
 {
 	CamelMimeFilter *filter;
-	size_t outlen, outpre;
-	char *outbuf;
+	gsize outlen, outpre;
+	gchar *outbuf;
 
 	g_return_val_if_fail (in != NULL, NULL);
 
 	filter = camel_mime_filter_tohtml_new (flags, colour);
 
-	camel_mime_filter_complete (filter, (char *) in, strlen (in), 0,
+	camel_mime_filter_complete (filter, (gchar *) in, strlen (in), 0,
 				    &outbuf, &outlen, &outpre);
 
 	outbuf = g_strndup (outbuf, outlen);
