@@ -5,7 +5,7 @@
  * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
  *	    Michael Zucchi <notzed@ximian.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -18,11 +18,10 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
-
 #ifndef CAMEL_STREAM_MEM_H
 #define CAMEL_STREAM_MEM_H 1
 
@@ -41,8 +40,8 @@ typedef struct _CamelStreamMemClass CamelStreamMemClass;
 struct _CamelStreamMem {
 	CamelSeekableStream parent_object;
 
-	unsigned int owner:1;	/* do we own the buffer? */
-	unsigned int secure:1;	/* do we clear the buffer on finalise (if we own it) */
+	guint owner:1;	/* do we own the buffer? */
+	guint secure:1;	/* do we clear the buffer on finalise (if we own it) */
 	GByteArray *buffer;
 };
 
@@ -58,14 +57,14 @@ CamelType camel_stream_mem_get_type (void);
 /* public methods */
 CamelStream *camel_stream_mem_new(void);
 CamelStream *camel_stream_mem_new_with_byte_array(GByteArray *buffer);
-CamelStream *camel_stream_mem_new_with_buffer(const char *buffer, size_t len);
+CamelStream *camel_stream_mem_new_with_buffer(const gchar *buffer, gsize len);
 
 /* 'secure' data, currently just clears memory on finalise */
 void camel_stream_mem_set_secure(CamelStreamMem *mem);
 
 /* these are really only here for implementing classes */
 void camel_stream_mem_set_byte_array(CamelStreamMem *mem, GByteArray *buffer);
-void camel_stream_mem_set_buffer(CamelStreamMem *mem, const char *buffer, size_t len);
+void camel_stream_mem_set_buffer(CamelStreamMem *mem, const gchar *buffer, gsize len);
 
 G_END_DECLS
 
