@@ -46,6 +46,7 @@
 #include "camel-vee-summary.h"
 #include "camel-string-utils.h"
 #include "camel-vee-folder.h"
+#include "camel-vtrash-folder.h"
 
 #define d(x)
 #define dd(x) (camel_debug("vfolder")?(x):0)
@@ -1093,7 +1094,6 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 	GPtrArray *match, *all;
 	GHashTable *allhash, *matchhash, *fullhash;
 	GSList *del_list = NULL;
-	CamelFolder *f = source;
 	CamelFolder *folder = (CamelFolder *)vf;
 	gint i, n, count, start, last;
 	struct _update_data u;
@@ -1114,8 +1114,12 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 
 	camel_vee_folder_hash_folder(source, u.hash);
 	shash = g_strdup_printf("%c%c%c%c%c%c%c%c", u.hash[0], u.hash[1], u.hash[2], u.hash[3], u.hash[4], u.hash[5], u.hash[6], u.hash[7]);
-	if (!g_hash_table_lookup (vf->hashes, shash))
+	if (!g_hash_table_lookup (vf->hashes, shash)) {
 		g_hash_table_insert (vf->hashes, g_strdup(shash), source->summary);
+	}
+	if (folder_unmatched && !g_hash_table_lookup (folder_unmatched->hashes, shash)) {
+		g_hash_table_insert (folder_unmatched->hashes, g_strdup (shash), source->summary);
+	}
 
 	/* if we have no expression, or its been cleared, then act as if no matches */
 	if (vf->expression == NULL) {
@@ -1129,7 +1133,7 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 			/* We take this to mean the results have not been cached.
 			 * XXX: It will also trigger if the result set is empty. */
 			match == NULL) {
-			match = camel_folder_search_by_expression(f, vf->expression, ex);
+			match = camel_folder_search_by_expression(source, vf->expression, ex);
 			if (match == NULL) /* Search failed */
 				return 0;
 			rebuilded = TRUE;
@@ -1148,21 +1152,22 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 
 	CAMEL_VEE_FOLDER_LOCK(vf, summary_lock);
 
-	/* we build 2 hash tables, one for all uid's not matched, the other for all matched uid's,
-	   we just ref the real memory */
+	/* we build 2 hash tables, one for all uid's not matched, the
+	   other for all matched uid's, we just ref the real memory */
 	matchhash = g_hash_table_new(g_str_hash, g_str_equal);
 	for (i=0;i<match->len;i++)
 		g_hash_table_insert(matchhash, match->pdata[i], GINT_TO_POINTER (1));
 
 	allhash = g_hash_table_new(g_str_hash, g_str_equal);
 	fullhash = g_hash_table_new(g_str_hash, g_str_equal);
-	all = camel_folder_summary_array(f->summary);
+	all = camel_folder_summary_array(source->summary);
 	for (i=0;i<all->len;i++) {
 		if (g_hash_table_lookup(matchhash, all->pdata[i]) == NULL)
 			g_hash_table_insert(allhash, all->pdata[i], GINT_TO_POINTER (1));
 		g_hash_table_insert(fullhash, all->pdata[i], GINT_TO_POINTER (1));
 
 	}
+	/* remove uids that can't be found in the source folder */
 	count = match->len;
 	for (i=0; i<count; i++) {
 		if (!g_hash_table_lookup(fullhash, match->pdata[i])) {
@@ -1178,7 +1183,9 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 	if (folder_unmatched != NULL)
 		CAMEL_VEE_FOLDER_LOCK(folder_unmatched, summary_lock);
 
-	/* scan, looking for "old" uid's to be removed */
+	/* scan, looking for "old" uid's to be removed. "old" uid's
+	   are those that are from previous added sources (not in
+	   current source) */
 	start = -1;
 	last = -1;
 	count = camel_folder_summary_count(folder->summary);
@@ -1295,8 +1302,8 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 		g_ptr_array_foreach (match, (GFunc) camel_pstring_free, NULL);
 		g_ptr_array_free(match, TRUE);
 	} else
-		camel_folder_search_free(f, match);
-	camel_folder_free_summary (f, all);
+		camel_folder_search_free(source, match);
+	camel_folder_free_summary (source, all);
 
 	if (unmatched_changes) {
 		camel_object_trigger_event((CamelObject *)folder_unmatched, "folder_changed", unmatched_changes);
@@ -1936,12 +1943,18 @@ static void
 vee_remove_folder(CamelVeeFolder *vf, CamelFolder *sub)
 {
 	gchar *shash, hash[8];
+	CamelVeeFolder *folder_unmatched = vf->parent_vee_store ? vf->parent_vee_store->folder_unmatched : NULL;
 
 	camel_vee_folder_hash_folder(sub, hash);
 	vee_folder_remove_folder(vf, sub);
 	shash = g_strdup_printf("%c%c%c%c%c%c%c%c", hash[0], hash[1], hash[2], hash[3], hash[4], hash[5], hash[6], hash[7]);
-	if (g_hash_table_lookup (vf->hashes, shash))
+	if (g_hash_table_lookup (vf->hashes, shash)) {
 		g_hash_table_remove (vf->hashes, shash);
+	}
+
+	if (folder_unmatched && g_hash_table_lookup (folder_unmatched->hashes, shash)) {
+		g_hash_table_remove (folder_unmatched->hashes, shash);
+	}
 
 	g_free(shash);
 
