@@ -20,7 +20,6 @@
  *
  */
 
-
 #ifndef _CAMEL_VTRASH_FOLDER_H
 #define _CAMEL_VTRASH_FOLDER_H
 
@@ -39,7 +38,7 @@ typedef struct _CamelVTrashFolderClass CamelVTrashFolderClass;
 #define CAMEL_VTRASH_NAME ".#evolution/Trash"
 #define CAMEL_VJUNK_NAME ".#evolution/Junk"
 
-typedef enum _camel_vtrash_folder_t {
+typedef enum {
 	CAMEL_VTRASH_FOLDER_TRASH,
 	CAMEL_VTRASH_FOLDER_JUNK,
 	CAMEL_VTRASH_FOLDER_LAST
@@ -48,13 +47,13 @@ typedef enum _camel_vtrash_folder_t {
 struct _CamelVTrashFolder {
 	CamelVeeFolder parent;
 
-	enum _camel_vtrash_folder_t type;
+	camel_vtrash_folder_t type;
 	guint32 bit;
 };
 
 struct _CamelVTrashFolderClass {
 	CamelVeeFolderClass parent_class;
-	
+
 };
 
 CamelType       camel_vtrash_folder_get_type    (void);
