@@ -2045,7 +2045,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 		/* Set Message Id */
 		message_id = e_gw_item_get_message_id (item);
 		if (message_id)
-			camel_medium_add_header (CAMEL_MEDIUM (msg), "Message-Id", message_id);
+			camel_medium_add_header (CAMEL_MEDIUM (msg), "Message-ID", message_id);
 
 		/* Set parent threads */
 		parent_threads = e_gw_item_get_parent_thread_ids (item);
