@@ -1,11 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- * 
+ *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
- * Copyright (C) 2000 Ximian (www.ximian.com).
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -45,7 +45,7 @@ static CamelProviderConfEntry mh_conf_entries[] = {
 	CAMEL_PROVIDER_CONF_DEFAULT_PATH,
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "general", NULL, N_("Options") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "dotfolders", NULL,
-	  N_("_Use the `.folders' folder summary file (exmh)"), "0" },
+	  N_("_Use the '.folders' folder summary file (exmh)"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_END }
 };
@@ -135,10 +135,10 @@ static CamelProvider spool_directory_provider = {
 #endif
 
 /* build a canonical 'path' */
-static char *
-make_can_path(char *p, char *o)
+static gchar *
+make_can_path(gchar *p, gchar *o)
 {
-	char c, last, *start = o;
+	gchar c, last, *start = o;
 
 	d(printf("canonical '%s' = ", p));
 
@@ -163,13 +163,13 @@ make_can_path(char *p, char *o)
 #define get_can_path(p) ((p == NULL) ? NULL : (make_can_path ((p), g_alloca (strlen (p) + 1))))
 
 static guint
-local_url_hash (const void *v)
+local_url_hash (gconstpointer v)
 {
 	const CamelURL *u = v;
 	guint hash = 0;
-	
+
 #define ADD_HASH(s) if (s) hash ^= g_str_hash (s);
-	
+
 	ADD_HASH (u->protocol);
 	ADD_HASH (u->user);
 	ADD_HASH (u->authmech);
@@ -179,12 +179,12 @@ local_url_hash (const void *v)
 	ADD_HASH (u->path);
 	ADD_HASH (u->query);
 	hash ^= u->port;
-	
+
 	return hash;
 }
 
-static int
-check_equal (char *s1, char *s2)
+static gint
+check_equal (gchar *s1, gchar *s2)
 {
 	if (s1 == NULL || *s1 == 0) {
 		if (s2 == NULL || *s2 == 0)
@@ -192,18 +192,18 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-	
+
 	if (s2 == NULL)
 		return FALSE;
 
 	return strcmp (s1, s2) == 0;
 }
 
-static int
-local_url_equal(const void *v, const void *v2)
+static gint
+local_url_equal(gconstpointer v, gconstpointer v2)
 {
 	const CamelURL *u1 = v, *u2 = v2;
-	char *p1, *p2;
+	gchar *p1, *p2;
 
 	p1 = get_can_path(u1->path);
 	p2 = get_can_path(u2->path);
@@ -214,9 +214,9 @@ local_url_equal(const void *v, const void *v2)
 void camel_provider_module_init(void)
 {
 #ifndef G_OS_WIN32
-	char *path;
+	gchar *path;
 #endif
-	static int init = 0;
+	static gint init = 0;
 
 	if (init)
 		abort();
