@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* e-uid.c - Unique ID generator.
  *
- * Copyright (C) 2002 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -30,25 +30,25 @@
 
 /**
  * e_uid_new:
- * 
+ *
  * Generate a new unique string for use e.g. in account lists.
- * 
+ *
  * Return value: The newly generated UID.  The caller should free the string
  * when it's done with it.
  **/
-char *
+gchar *
 e_uid_new (void)
 {
-	static int serial;
-	static char *hostname;
+	static gint serial;
+	static gchar *hostname;
 
 	if (!hostname) {
-		hostname = (char *) g_get_host_name ();
+		hostname = (gchar *) g_get_host_name ();
 	}
 
 	return g_strdup_printf ("%lu.%lu.%d@%s",
-				(unsigned long) time (NULL),
-				(unsigned long) getpid (),
+				(gulong) time (NULL),
+				(gulong) getpid (),
 				serial++,
 				hostname);
 }
