@@ -172,7 +172,7 @@ e_name_selector_entry_class_init (ENameSelectorEntryClass *name_selector_entry_c
 	g_type_class_add_private (object_class, sizeof(ENameSelectorEntryPrivate));
 }
 
-/* Remove unquoted commas from string */
+/* Remove unquoted commas and control characters from string */
 static gchar *
 sanitize_string (const gchar *string)
 {
@@ -192,6 +192,8 @@ sanitize_string (const gchar *string)
 			quoted = ~quoted;
 		else if (c == ',' && !quoted)
 			continue;
+		else if (c == '\t' || c == '\n')
+			continue;
 
 		g_string_append_unichar (gstring, c);
 	}
@@ -1527,6 +1529,20 @@ entry_activate (ENameSelectorEntry *name_selector_entry)
 		clear_completion_model (name_selector_entry);
 }
 
+static void
+update_text (ENameSelectorEntry *name_selector_entry, const gchar *text)
+{
+	gint start = 0, end = 0;
+	gboolean has_selection;
+
+	has_selection = gtk_editable_get_selection_bounds (GTK_EDITABLE (name_selector_entry), &start, &end);
+
+	gtk_entry_set_text (GTK_ENTRY (name_selector_entry), text);
+
+	if (has_selection)
+		gtk_editable_select_region (GTK_EDITABLE (name_selector_entry), start, end);
+}
+
 static void
 sanitize_entry (ENameSelectorEntry *name_selector_entry)
 {
@@ -1563,7 +1579,7 @@ sanitize_entry (ENameSelectorEntry *name_selector_entry)
 	}
 	g_list_free (del);
 
-	gtk_entry_set_text (GTK_ENTRY (name_selector_entry), str->str);
+	update_text (name_selector_entry, str->str);
 
 	g_string_free (str, TRUE);
 
@@ -1576,11 +1592,48 @@ sanitize_entry (ENameSelectorEntry *name_selector_entry)
 static gboolean
 user_focus_in (ENameSelectorEntry *name_selector_entry, GdkEventFocus *event_focus)
 {
-	/*
-	 * To preserve selected text, do not propagate the event any more.
-	 */
+	gint n;
+	GList *l, *known;
+	GString *str = g_string_new ("");
+	EDestination *dest_dummy = e_destination_new ();
 
-	return TRUE;
+	g_signal_handlers_block_matched (name_selector_entry, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, name_selector_entry);
+	g_signal_handlers_block_matched (name_selector_entry->destination_store, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, name_selector_entry);
+
+	known = e_destination_store_list_destinations (name_selector_entry->destination_store);
+	for (l = known, n = 0; l != NULL; l = l->next, n++) {
+		EDestination *dest = l->data;
+
+		if (dest) {
+			gchar *text;
+
+			text = get_destination_textrep (dest);
+			if (text) {
+				if (str->str && str->str[0])
+					g_string_append (str, ", ");
+
+				g_string_append (str, text);
+			}
+			g_free (text);
+		}
+	}
+	g_list_free (known);
+
+	/* Add a blank destination */
+	e_destination_store_append_destination (name_selector_entry->destination_store, dest_dummy);
+	if (str->str && str->str[0])
+		g_string_append (str, ", ");
+
+	gtk_entry_set_text (GTK_ENTRY (name_selector_entry), str->str);
+
+	g_string_free (str, TRUE);
+
+	g_signal_handlers_unblock_matched (name_selector_entry->destination_store, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, name_selector_entry);
+	g_signal_handlers_unblock_matched (name_selector_entry, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, name_selector_entry);
+
+	generate_attribute_list (name_selector_entry);
+
+	return FALSE;
 }
 
 static gboolean
