@@ -50,7 +50,6 @@ struct _OfflineListenerPrivate
 	gboolean is_offline_now;
 };
 
-
 static void
 set_online_status (OfflineListener *offline_listener, gboolean is_offline)
 {
@@ -67,7 +66,7 @@ set_online_status (OfflineListener *offline_listener, gboolean is_offline)
 }
 
 static void
-online_status_changed (GConfClient *client, int cnxn_id, GConfEntry *entry, gpointer data)
+online_status_changed (GConfClient *client, gint cnxn_id, GConfEntry *entry, gpointer data)
 {
 	GConfValue *value;
 	gboolean offline;
@@ -87,7 +86,6 @@ online_status_changed (GConfClient *client, int cnxn_id, GConfEntry *entry, gpoi
 
 }
 
-
 static void
 setup_offline_listener (OfflineListener *offline_listener)
 {
@@ -120,7 +118,6 @@ offline_listener_new (EDataBookFactory *book_factory)
 
 }
 
-
 static void
 offline_listener_dispose (GObject *object)
 {
@@ -157,8 +154,6 @@ offline_listener_init (OfflineListener *listener)
 
 }
 
-
-
 static void
 offline_listener_class_init (OfflineListener *klass)
 {
@@ -170,11 +165,8 @@ offline_listener_class_init (OfflineListener *klass)
 	object_class->dispose = offline_listener_dispose;
 	object_class->finalize = offline_listener_finalize;
 
-
-
 }
 
-
 GType
 offline_listener_get_type (void)
 {
